
> Note: This package is in the dangerous land of `0.x.y` versions and may be subject to breaking
> changes with minor version increments.

# nr.pylang.utils

Utilities for Python constructs (class and function definitions, exception
handling, modules and type annotations).

__Note__: `typing` is an optional dependency and is thus not listed in the
requirements for this package.

---

<p align="center">Copyright &copy; 2020 Niklas Rosenstein</p>
